from typing import List
from data_fabric.components import main

def data_fabric(
    query: str = "",
    query_tool_title: str = "",
    data_grid_title: str = "",
    data_visualization_title: str = "",
    databases: List[str] = [],
    tables: List[dict] = [],
    columns: List[dict] = [],
    error: str = "",
    show_execute=True,
    on_database_change=None,
    on_table_change=None,
    on_generate_query=None,
    on_copy_query=None,
    on_execute_query=None,
    data={},
    show_data_grid=True,
    show_charts=True,
):
    
    main(
        query=query,
        query_tool_title=query_tool_title,
        data_grid_title=data_grid_title,
        data_visualization_title=data_visualization_title,
        databases=databases,
        tables=tables,
        columns=columns,
        data=data,
        error=error,
        show_execute=show_execute,
        on_database_change=on_database_change,
        on_table_change=on_table_change,
        on_generate_query=on_generate_query,
        on_copy_query=on_copy_query,
        on_execute_query=on_execute_query,
        show_data_grid=show_data_grid,
        show_charts=show_charts,
    )


from typing import List
import query_tool as qt
import data_grid as dg
import data_visualization as dv
import streamlit as st

def main(
        query: str = "",
        query_tool_title: str = "",
        data_grid_title: str = "",
        data_visualization_title: str = "",
        databases: List[str] = [],
        tables: List[dict] = [],
        columns: List[dict] = [],
        data={},
        error="",
        show_execute=True,
        on_database_change=None,
        on_table_change=None,
        on_generate_query=None,
        on_copy_query=None,
        on_execute_query=None,
        show_data_grid=True,
        show_charts=True,
    ):
    

    with open('style.css') as f:
        st.markdown(f'<style>{f.read()}</style>', unsafe_allow_html=True)

    render_query_tool(
        query=query,
        title=query_tool_title,
        databases=databases,
        tables=tables,
        columns=columns,
        error=error,
        show_execute=show_execute,
        on_database_change=on_database_change,
        on_table_change=on_table_change,
        on_generate_query=on_generate_query,
        on_copy_query=on_copy_query,
        on_execute_query=on_execute_query,
    )

    # if query != "":
    #   st.button("Execute", on_click=on_execute_query)
    st.write("")
    st.write("")
    if show_data_grid == True:
        render_data_grid(
            title=data_grid_title,
            rows=data.get("rows", []),
            columns=data.get("columns", []),
        )

    if show_charts == True:
        render_data_visualizer(
            title=data_visualization_title,
            rows=data.get("rows", []),
        )

def render_query_tool(
        query: str = "",
        title: str = "",
        databases: List[str] = [],
        tables: List[dict] = [],
        columns: List[dict] = [],
        show_execute=True,
        error="",
        on_database_change=None,
        on_table_change=None,
        on_generate_query=None,
        on_copy_query=None,
        on_execute_query=None,
):
    qt.query_tool(
        query=query,
        title=title,
        databases=databases,
        tables=tables,
        columns=columns,
        error=error,
        show_execute=show_execute,
        on_database_change=on_database_change,
        on_table_change=on_table_change,
        on_generate_query=on_generate_query,
        on_copy_query=on_copy_query,
        on_execute_query=on_execute_query,
        key="query_builder",
    )  

def render_data_grid(title: str="", rows: List = [], columns: List = []):
    dg.data_grid(
        title=title,
        rows=rows,
        columns=columns,
        key="data_grid",
    )

def render_data_visualizer(title="", rows=[]):
    dv.data_visualizer(
        title=title,
        data=rows,
        key="data_visualizer",
    )


import setuptools

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setuptools.setup(
    name="bp_data_fabric",
    version="1.0.6",
    author="Bluepinapple",
    author_email="viveksthul@bluepinapple.com",
    description="",    
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.8.10",
    install_requires=[
        # By definition, a Custom Component depends on Streamlit.
        # If your component has other Python dependencies, list
        # them here.
        "streamlit >= 1.20.0",
        "bp-query-tool >= 0.0.3",
        "bp-data-grid >= 0.0.9",
        "bp-data-visualization >= 0.0.9",
    ],
)
